@@ -12,7 +12,7 @@
 #    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
-#    under the License.import logging
+#    under the License.
 
 import json
 import logging
@@ -250,9 +250,9 @@ class MonascaProxyView(TemplateView):
             for dimension in dimensions_str_array:
                 dimension_name_value = dimension.split(':')
                 if len(dimension_name_value) == 2:
-                    name = dimension_name_value[0]
-                    value = dimension_name_value[1]
-                    dim_dict[name] = urllib.unquote(value).decode('utf8')
+                    name = dimension_name_value[0].encode('utf8')
+                    value = dimension_name_value[1].encode('utf8')
+                    dim_dict[name] = urllib.unquote(value)
                 else:
                     raise Exception('Dimensions are malformed')
 
